SATOSA oidcop frontend
----------------------

SATOSA Frontend based on idetity python oidcop.

## Requirements

- satosa
- mongodb, see [Satosa-Saml2Spid mongo example](https://github.com/italia/Satosa-Saml2Spid/tree/oidcop/mongo).


## Setup

````
pip install satosa_oidcop
````

## Demo

[Satosa-Saml2Spid](https://github.com/italia/Satosa-Saml2Spid/) is a custom Satosa configuration to deal with many SAML2 and OIDC Relying parties and many eduGain and SPID Identity Provider.


## Contributions

Feel free to open issues and pull requests, we build communities!

## Authors

- Giuseppe De Marco <at> Università della Calabria

## Credits

- Roland Hedberg
- Andrea Ranaldi <at> ISTRA Ambiente
- Identity Python Community
